Crate ax_sync

Crate ax_sync 

ArceOS synchronization primitives.

Currently supported primitives:

  • Mutex: A mutual exclusion primitive.
  • mod spin: spinlocks imported from the [ax-kspin] crate.

Cargo Features

  • multitask: For use in the multi-threaded environments. If the feature is not enabled, Mutex will be an alias of spin::SpinNoIrq. This feature is enabled by default.

Re-exports

pub use ax_kspin as spin;

Type Aliases

MutexNon-multitask
A spin lock that disables kernel preemption and local IRQs while trying to lock, and re-enables it after unlocking.
MutexGuardNon-multitask
A guard that provides mutable data access for SpinNoIrq.